# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions
from typing_extensions import Literal

import httpx

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .v3.v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .ingest import (
    IngestResource,
    AsyncIngestResource,
    IngestResourceWithRawResponse,
    AsyncIngestResourceWithRawResponse,
    IngestResourceWithStreamingResponse,
    AsyncIngestResourceWithStreamingResponse,
)
from ...types import (
    paper_add_author_params,
    paper_admin_vote_params,
    paper_email_author_params,
    paper_process_metadata_params,
    paper_request_ai_latest_params,
    paper_set_github_repository_params,
    paper_process_abstract_embed_params,
)
from .private import (
    PrivateResource,
    AsyncPrivateResource,
    PrivateResourceWithRawResponse,
    AsyncPrivateResourceWithRawResponse,
    PrivateResourceWithStreamingResponse,
    AsyncPrivateResourceWithStreamingResponse,
)
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from .metadata import (
    MetadataResource,
    AsyncMetadataResource,
    MetadataResourceWithRawResponse,
    AsyncMetadataResourceWithRawResponse,
    MetadataResourceWithStreamingResponse,
    AsyncMetadataResourceWithStreamingResponse,
)
from .versions import (
    VersionsResource,
    AsyncVersionsResource,
    VersionsResourceWithRawResponse,
    AsyncVersionsResourceWithRawResponse,
    VersionsResourceWithStreamingResponse,
    AsyncVersionsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .kickoff_daily_github_stars import (
    KickoffDailyGitHubStarsResource,
    AsyncKickoffDailyGitHubStarsResource,
    KickoffDailyGitHubStarsResourceWithRawResponse,
    AsyncKickoffDailyGitHubStarsResourceWithRawResponse,
    KickoffDailyGitHubStarsResourceWithStreamingResponse,
    AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse,
)
from ...types.paper_vote_response import PaperVoteResponse
from ...types.paper_unclaim_response import PaperUnclaimResponse
from ...types.paper_add_author_response import PaperAddAuthorResponse
from ...types.paper_admin_vote_response import PaperAdminVoteResponse
from ...types.paper_kickoff_ai_response import PaperKickoffAIResponse
from ...types.paper_crx_pdf_hit_response import PaperCrxPdfHitResponse
from ...types.paper_email_author_response import PaperEmailAuthorResponse
from ...types.paper_crx_pdf_click_response import PaperCrxPdfClickResponse
from ...types.paper_toggle_follow_response import PaperToggleFollowResponse
from ...types.paper_get_paper_info_response import PaperGetPaperInfoResponse
from ...types.paper_kickoff_bibtex_response import PaperKickoffBibtexResponse
from ...types.paper_kickoff_github_response import PaperKickoffGitHubResponse
from ...types.paper_crx_abstract_hit_response import PaperCrxAbstractHitResponse
from ...types.paper_process_metadata_response import PaperProcessMetadataResponse
from ...types.paper_request_ai_latest_response import PaperRequestAILatestResponse
from ...types.paper_crx_abstract_click_response import PaperCrxAbstractClickResponse
from ...types.paper_get_crx_paper_info_response import PaperGetCrxPaperInfoResponse
from ...types.paper_kickoff_recent_papers_response import PaperKickoffRecentPapersResponse
from ...types.paper_set_github_repository_response import PaperSetGitHubRepositoryResponse
from ...types.paper_translate_ai_overview_response import PaperTranslateAIOverviewResponse
from ...types.paper_kickoff_abstract_embed_response import PaperKickoffAbstractEmbedResponse
from ...types.paper_process_abstract_embed_response import PaperProcessAbstractEmbedResponse
from ...types.paper_kickoff_paper_categorization_response import PaperKickoffPaperCategorizationResponse
from ...types.paper_request_ai_translation_latest_response import PaperRequestAITranslationLatestResponse

__all__ = ["PapersResource", "AsyncPapersResource"]


class PapersResource(SyncAPIResource):
    @cached_property
    def versions(self) -> VersionsResource:
        return VersionsResource(self._client)

    @cached_property
    def metadata(self) -> MetadataResource:
        return MetadataResource(self._client)

    @cached_property
    def ingest(self) -> IngestResource:
        return IngestResource(self._client)

    @cached_property
    def private(self) -> PrivateResource:
        return PrivateResource(self._client)

    @cached_property
    def kickoff_daily_github_stars(self) -> KickoffDailyGitHubStarsResource:
        return KickoffDailyGitHubStarsResource(self._client)

    @cached_property
    def v3(self) -> V3Resource:
        return V3Resource(self._client)

    @cached_property
    def v2(self) -> V2Resource:
        return V2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> PapersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return PapersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PapersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return PapersResourceWithStreamingResponse(self)

    def add_author(
        self,
        paper_id: str,
        *,
        author_email: str,
        should_email: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperAddAuthorResponse:
        """
        Add a new author to a paper

        Source file: `api-server/src/controllers/v2/papers/add-new-author.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/add-author",
            body=maybe_transform(
                {
                    "author_email": author_email,
                    "should_email": should_email,
                },
                paper_add_author_params.PaperAddAuthorParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperAddAuthorResponse,
        )

    def admin_vote(
        self,
        paper_id: str,
        *,
        entry: float,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperAdminVoteResponse:
        """
        Set paper vote count (admin only)

        Source file:
        `api-server/src/controllers/v2/papers/admin-vote-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/admin-vote",
            body=maybe_transform({"entry": entry}, paper_admin_vote_params.PaperAdminVoteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperAdminVoteResponse,
        )

    def crx_abstract_click(
        self,
        ref: str,
        *,
        pid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxAbstractClickResponse:
        """
        Legacy route for v1 browser extensions to track abstract page clicks

        Source file:
        `api-server/src/controllers/v1/papers/crxabstractclick.controller.ts`

        Args:
          pid: Paper ID

          ref: Referrer

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        if not ref:
            raise ValueError(f"Expected a non-empty value for `ref` but received {ref!r}")
        return self._get(
            f"/v1/papers/crxabstractclick/{pid}/{ref}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxAbstractClickResponse,
        )

    def crx_abstract_hit(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxAbstractHitResponse:
        """
        Legacy route for v1 browser extensions to track abstract page hits

        Source file: `api-server/src/controllers/v1/papers/crxabstracthit.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return self._get(
            f"/v1/papers/crxabstracthit/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxAbstractHitResponse,
        )

    def crx_pdf_click(
        self,
        ref: str,
        *,
        pid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxPdfClickResponse:
        """
        Legacy route for v1 browser extensions to track PDF page clicks

        Source file: `api-server/src/controllers/v1/papers/crxpdfclick.controller.ts`

        Args:
          pid: Paper ID

          ref: Referrer

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        if not ref:
            raise ValueError(f"Expected a non-empty value for `ref` but received {ref!r}")
        return self._get(
            f"/v1/papers/crxpdfclick/{pid}/{ref}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxPdfClickResponse,
        )

    def crx_pdf_hit(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxPdfHitResponse:
        """
        Legacy route for v1 browser extensions to track PDF page hits

        Source file: `api-server/src/controllers/v1/papers/crxpdfhit.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return self._get(
            f"/v1/papers/crxpdfhit/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxPdfHitResponse,
        )

    def email_author(
        self,
        paper_id: str,
        *,
        author_individual_email: str,
        email_author_name: str,
        paper_name: str,
        type: Literal["comment", "trending"],
        ignore_duplicate_error: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperEmailAuthorResponse:
        """
        Send email to individual author about paper comments or trending

        Source file:
        `api-server/src/controllers/v2/papers/email-individual-author.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/email-author",
            body=maybe_transform(
                {
                    "author_individual_email": author_individual_email,
                    "email_author_name": email_author_name,
                    "paper_name": paper_name,
                    "type": type,
                    "ignore_duplicate_error": ignore_duplicate_error,
                },
                paper_email_author_params.PaperEmailAuthorParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperEmailAuthorResponse,
        )

    def get_crx_paper_info(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperGetCrxPaperInfoResponse:
        """
        Legacy route for v1 browser extensions to get paper information

        Source file:
        `api-server/src/controllers/v1/papers/getcrxpaperinfo.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return self._get(
            f"/v1/papers/getcrxpaperinfo/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperGetCrxPaperInfoResponse,
        )

    def get_paper_info(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperGetPaperInfoResponse:
        """
        Legacy route for getting paper information from arXiv abstract pages

        Source file: `api-server/src/controllers/v1/papers/getpaperinfo.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return self._get(
            f"/v1/papers/getpaperinfo/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperGetPaperInfoResponse,
        )

    def kickoff_abstract_embed(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffAbstractEmbedResponse:
        """
        Kickoff background job to generate abstract embeddings for paper versions

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-version-abstract-embed.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-paper-version-abstract-embed",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffAbstractEmbedResponse,
        )

    def kickoff_ai(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffAIResponse:
        """
        Kickoff background job to generate AI overviews for papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-ai.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-paper-ai",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffAIResponse,
        )

    def kickoff_bibtex(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffBibtexResponse:
        """
        Kickoff background job to generate bibtex for papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-bibtex.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-paper-bibtex",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffBibtexResponse,
        )

    def kickoff_github(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffGitHubResponse:
        """
        Kickoff background job to link papers with GitHub repositories

        Source file: `api-server/src/controllers/v2/papers/kickoff-github.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-github",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffGitHubResponse,
        )

    def kickoff_paper_categorization(
        self,
        all: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffPaperCategorizationResponse:
        """
        Kickoff background job to categorize papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-categorization.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not all:
            raise ValueError(f"Expected a non-empty value for `all` but received {all!r}")
        return self._post(
            f"/v2/papers/kickoff-paper-categorization/{all}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffPaperCategorizationResponse,
        )

    def kickoff_recent_papers(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffRecentPapersResponse:
        """
        Kickoff background job to ingest recent papers from arXiv

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-recent-papers.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-recent-papers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffRecentPapersResponse,
        )

    def mark_viewed(
        self,
        upid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Track paper view event for analytics

        Source file:
        `api-server/src/controllers/v2/papers/mark-paper-view.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return self._post(
            f"/v2/papers/{upid}/view",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @typing_extensions.deprecated("deprecated")
    def process_abstract_embed(
        self,
        *,
        paper_version_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperProcessAbstractEmbedResponse:
        """
        Process abstract embedding for a paper version

        Source file:
        `api-server/src/controllers/v2/papers/process-paper-version-abstract-embed.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/papers/process-paper-version-abstract-embed",
            body=maybe_transform(
                {"paper_version_id": paper_version_id},
                paper_process_abstract_embed_params.PaperProcessAbstractEmbedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperProcessAbstractEmbedResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def process_metadata(
        self,
        *,
        metadata: paper_process_metadata_params.Metadata,
        universal_paper_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperProcessMetadataResponse:
        """
        Process various metadata for a paper (thumbnail, github, bibtex, etc.)

        Source file:
        `api-server/src/controllers/v2/papers/process-metadata.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v2/papers/process-metadata",
            body=maybe_transform(
                {
                    "metadata": metadata,
                    "universal_paper_id": universal_paper_id,
                },
                paper_process_metadata_params.PaperProcessMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperProcessMetadataResponse,
        )

    def request_ai_latest(
        self,
        upid: str,
        *,
        preferred_language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperRequestAILatestResponse:
        """
        Request AI overview generation for the latest paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return self._post(
            f"/v2/papers/{upid}/request-ai",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"preferred_language": preferred_language},
                    paper_request_ai_latest_params.PaperRequestAILatestParams,
                ),
            ),
            cast_to=PaperRequestAILatestResponse,
        )

    def request_ai_translation_latest(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        upid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperRequestAITranslationLatestResponse:
        """
        Request AI overview translation for the latest paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-translation-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return self._post(
            f"/v2/papers/{upid}/request-ai-translation/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperRequestAITranslationLatestResponse,
        )

    def set_github_repository(
        self,
        paper_id: str,
        *,
        github: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperSetGitHubRepositoryResponse:
        """
        Set GitHub repository for a paper

        Source file: `api-server/src/controllers/v2/papers/set-github.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/github",
            body=maybe_transform({"github": github}, paper_set_github_repository_params.PaperSetGitHubRepositoryParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperSetGitHubRepositoryResponse,
        )

    def toggle_follow(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperToggleFollowResponse:
        """
        Toggle paper follow status (add to Want to read folder or remove from all
        folders)

        Source file: `api-server/src/controllers/v2/papers/follow-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/follow",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperToggleFollowResponse,
        )

    @typing_extensions.deprecated("deprecated")
    def translate_ai_overview(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        paper_version_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperTranslateAIOverviewResponse:
        """
        Translate AI overview to specified language

        Source file:
        `api-server/src/controllers/v2/papers/translate-ai-overview.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version_id:
            raise ValueError(f"Expected a non-empty value for `paper_version_id` but received {paper_version_id!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return self._post(
            f"/v2/papers/translate-ai-overview/{paper_version_id}/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperTranslateAIOverviewResponse,
        )

    def unclaim(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperUnclaimResponse:
        """
        Remove authorship claim from a paper

        Source file: `api-server/src/controllers/v2/papers/unclaim-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/unclaim",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperUnclaimResponse,
        )

    def vote(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperVoteResponse:
        """
        Toggle vote for a paper

        Source file: `api-server/src/controllers/v2/papers/vote-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return self._post(
            f"/v2/papers/{paper_id}/vote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperVoteResponse,
        )


class AsyncPapersResource(AsyncAPIResource):
    @cached_property
    def versions(self) -> AsyncVersionsResource:
        return AsyncVersionsResource(self._client)

    @cached_property
    def metadata(self) -> AsyncMetadataResource:
        return AsyncMetadataResource(self._client)

    @cached_property
    def ingest(self) -> AsyncIngestResource:
        return AsyncIngestResource(self._client)

    @cached_property
    def private(self) -> AsyncPrivateResource:
        return AsyncPrivateResource(self._client)

    @cached_property
    def kickoff_daily_github_stars(self) -> AsyncKickoffDailyGitHubStarsResource:
        return AsyncKickoffDailyGitHubStarsResource(self._client)

    @cached_property
    def v3(self) -> AsyncV3Resource:
        return AsyncV3Resource(self._client)

    @cached_property
    def v2(self) -> AsyncV2Resource:
        return AsyncV2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPapersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPapersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPapersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncPapersResourceWithStreamingResponse(self)

    async def add_author(
        self,
        paper_id: str,
        *,
        author_email: str,
        should_email: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperAddAuthorResponse:
        """
        Add a new author to a paper

        Source file: `api-server/src/controllers/v2/papers/add-new-author.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/add-author",
            body=await async_maybe_transform(
                {
                    "author_email": author_email,
                    "should_email": should_email,
                },
                paper_add_author_params.PaperAddAuthorParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperAddAuthorResponse,
        )

    async def admin_vote(
        self,
        paper_id: str,
        *,
        entry: float,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperAdminVoteResponse:
        """
        Set paper vote count (admin only)

        Source file:
        `api-server/src/controllers/v2/papers/admin-vote-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/admin-vote",
            body=await async_maybe_transform({"entry": entry}, paper_admin_vote_params.PaperAdminVoteParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperAdminVoteResponse,
        )

    async def crx_abstract_click(
        self,
        ref: str,
        *,
        pid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxAbstractClickResponse:
        """
        Legacy route for v1 browser extensions to track abstract page clicks

        Source file:
        `api-server/src/controllers/v1/papers/crxabstractclick.controller.ts`

        Args:
          pid: Paper ID

          ref: Referrer

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        if not ref:
            raise ValueError(f"Expected a non-empty value for `ref` but received {ref!r}")
        return await self._get(
            f"/v1/papers/crxabstractclick/{pid}/{ref}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxAbstractClickResponse,
        )

    async def crx_abstract_hit(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxAbstractHitResponse:
        """
        Legacy route for v1 browser extensions to track abstract page hits

        Source file: `api-server/src/controllers/v1/papers/crxabstracthit.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return await self._get(
            f"/v1/papers/crxabstracthit/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxAbstractHitResponse,
        )

    async def crx_pdf_click(
        self,
        ref: str,
        *,
        pid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxPdfClickResponse:
        """
        Legacy route for v1 browser extensions to track PDF page clicks

        Source file: `api-server/src/controllers/v1/papers/crxpdfclick.controller.ts`

        Args:
          pid: Paper ID

          ref: Referrer

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        if not ref:
            raise ValueError(f"Expected a non-empty value for `ref` but received {ref!r}")
        return await self._get(
            f"/v1/papers/crxpdfclick/{pid}/{ref}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxPdfClickResponse,
        )

    async def crx_pdf_hit(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperCrxPdfHitResponse:
        """
        Legacy route for v1 browser extensions to track PDF page hits

        Source file: `api-server/src/controllers/v1/papers/crxpdfhit.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return await self._get(
            f"/v1/papers/crxpdfhit/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperCrxPdfHitResponse,
        )

    async def email_author(
        self,
        paper_id: str,
        *,
        author_individual_email: str,
        email_author_name: str,
        paper_name: str,
        type: Literal["comment", "trending"],
        ignore_duplicate_error: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperEmailAuthorResponse:
        """
        Send email to individual author about paper comments or trending

        Source file:
        `api-server/src/controllers/v2/papers/email-individual-author.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/email-author",
            body=await async_maybe_transform(
                {
                    "author_individual_email": author_individual_email,
                    "email_author_name": email_author_name,
                    "paper_name": paper_name,
                    "type": type,
                    "ignore_duplicate_error": ignore_duplicate_error,
                },
                paper_email_author_params.PaperEmailAuthorParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperEmailAuthorResponse,
        )

    async def get_crx_paper_info(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperGetCrxPaperInfoResponse:
        """
        Legacy route for v1 browser extensions to get paper information

        Source file:
        `api-server/src/controllers/v1/papers/getcrxpaperinfo.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return await self._get(
            f"/v1/papers/getcrxpaperinfo/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperGetCrxPaperInfoResponse,
        )

    async def get_paper_info(
        self,
        pid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperGetPaperInfoResponse:
        """
        Legacy route for getting paper information from arXiv abstract pages

        Source file: `api-server/src/controllers/v1/papers/getpaperinfo.controller.ts`

        Args:
          pid: Paper ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pid:
            raise ValueError(f"Expected a non-empty value for `pid` but received {pid!r}")
        return await self._get(
            f"/v1/papers/getpaperinfo/{pid}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperGetPaperInfoResponse,
        )

    async def kickoff_abstract_embed(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffAbstractEmbedResponse:
        """
        Kickoff background job to generate abstract embeddings for paper versions

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-version-abstract-embed.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-paper-version-abstract-embed",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffAbstractEmbedResponse,
        )

    async def kickoff_ai(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffAIResponse:
        """
        Kickoff background job to generate AI overviews for papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-ai.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-paper-ai",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffAIResponse,
        )

    async def kickoff_bibtex(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffBibtexResponse:
        """
        Kickoff background job to generate bibtex for papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-bibtex.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-paper-bibtex",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffBibtexResponse,
        )

    async def kickoff_github(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffGitHubResponse:
        """
        Kickoff background job to link papers with GitHub repositories

        Source file: `api-server/src/controllers/v2/papers/kickoff-github.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-github",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffGitHubResponse,
        )

    async def kickoff_paper_categorization(
        self,
        all: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffPaperCategorizationResponse:
        """
        Kickoff background job to categorize papers

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-paper-categorization.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not all:
            raise ValueError(f"Expected a non-empty value for `all` but received {all!r}")
        return await self._post(
            f"/v2/papers/kickoff-paper-categorization/{all}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffPaperCategorizationResponse,
        )

    async def kickoff_recent_papers(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperKickoffRecentPapersResponse:
        """
        Kickoff background job to ingest recent papers from arXiv

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-recent-papers.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-recent-papers",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperKickoffRecentPapersResponse,
        )

    async def mark_viewed(
        self,
        upid: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> object:
        """
        Track paper view event for analytics

        Source file:
        `api-server/src/controllers/v2/papers/mark-paper-view.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return await self._post(
            f"/v2/papers/{upid}/view",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_abstract_embed(
        self,
        *,
        paper_version_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperProcessAbstractEmbedResponse:
        """
        Process abstract embedding for a paper version

        Source file:
        `api-server/src/controllers/v2/papers/process-paper-version-abstract-embed.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/papers/process-paper-version-abstract-embed",
            body=await async_maybe_transform(
                {"paper_version_id": paper_version_id},
                paper_process_abstract_embed_params.PaperProcessAbstractEmbedParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperProcessAbstractEmbedResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def process_metadata(
        self,
        *,
        metadata: paper_process_metadata_params.Metadata,
        universal_paper_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperProcessMetadataResponse:
        """
        Process various metadata for a paper (thumbnail, github, bibtex, etc.)

        Source file:
        `api-server/src/controllers/v2/papers/process-metadata.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v2/papers/process-metadata",
            body=await async_maybe_transform(
                {
                    "metadata": metadata,
                    "universal_paper_id": universal_paper_id,
                },
                paper_process_metadata_params.PaperProcessMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperProcessMetadataResponse,
        )

    async def request_ai_latest(
        self,
        upid: str,
        *,
        preferred_language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperRequestAILatestResponse:
        """
        Request AI overview generation for the latest paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        return await self._post(
            f"/v2/papers/{upid}/request-ai",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"preferred_language": preferred_language},
                    paper_request_ai_latest_params.PaperRequestAILatestParams,
                ),
            ),
            cast_to=PaperRequestAILatestResponse,
        )

    async def request_ai_translation_latest(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        upid: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperRequestAITranslationLatestResponse:
        """
        Request AI overview translation for the latest paper version

        Source file:
        `api-server/src/controllers/v2/papers/request-ai-translation-latest.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not upid:
            raise ValueError(f"Expected a non-empty value for `upid` but received {upid!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return await self._post(
            f"/v2/papers/{upid}/request-ai-translation/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperRequestAITranslationLatestResponse,
        )

    async def set_github_repository(
        self,
        paper_id: str,
        *,
        github: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperSetGitHubRepositoryResponse:
        """
        Set GitHub repository for a paper

        Source file: `api-server/src/controllers/v2/papers/set-github.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/github",
            body=await async_maybe_transform(
                {"github": github}, paper_set_github_repository_params.PaperSetGitHubRepositoryParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperSetGitHubRepositoryResponse,
        )

    async def toggle_follow(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperToggleFollowResponse:
        """
        Toggle paper follow status (add to Want to read folder or remove from all
        folders)

        Source file: `api-server/src/controllers/v2/papers/follow-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/follow",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperToggleFollowResponse,
        )

    @typing_extensions.deprecated("deprecated")
    async def translate_ai_overview(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        paper_version_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperTranslateAIOverviewResponse:
        """
        Translate AI overview to specified language

        Source file:
        `api-server/src/controllers/v2/papers/translate-ai-overview.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version_id:
            raise ValueError(f"Expected a non-empty value for `paper_version_id` but received {paper_version_id!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return await self._post(
            f"/v2/papers/translate-ai-overview/{paper_version_id}/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperTranslateAIOverviewResponse,
        )

    async def unclaim(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperUnclaimResponse:
        """
        Remove authorship claim from a paper

        Source file: `api-server/src/controllers/v2/papers/unclaim-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/unclaim",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperUnclaimResponse,
        )

    async def vote(
        self,
        paper_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PaperVoteResponse:
        """
        Toggle vote for a paper

        Source file: `api-server/src/controllers/v2/papers/vote-paper.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_id:
            raise ValueError(f"Expected a non-empty value for `paper_id` but received {paper_id!r}")
        return await self._post(
            f"/v2/papers/{paper_id}/vote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PaperVoteResponse,
        )


class PapersResourceWithRawResponse:
    def __init__(self, papers: PapersResource) -> None:
        self._papers = papers

        self.add_author = to_raw_response_wrapper(
            papers.add_author,
        )
        self.admin_vote = to_raw_response_wrapper(
            papers.admin_vote,
        )
        self.crx_abstract_click = to_raw_response_wrapper(
            papers.crx_abstract_click,
        )
        self.crx_abstract_hit = to_raw_response_wrapper(
            papers.crx_abstract_hit,
        )
        self.crx_pdf_click = to_raw_response_wrapper(
            papers.crx_pdf_click,
        )
        self.crx_pdf_hit = to_raw_response_wrapper(
            papers.crx_pdf_hit,
        )
        self.email_author = to_raw_response_wrapper(
            papers.email_author,
        )
        self.get_crx_paper_info = to_raw_response_wrapper(
            papers.get_crx_paper_info,
        )
        self.get_paper_info = to_raw_response_wrapper(
            papers.get_paper_info,
        )
        self.kickoff_abstract_embed = to_raw_response_wrapper(
            papers.kickoff_abstract_embed,
        )
        self.kickoff_ai = to_raw_response_wrapper(
            papers.kickoff_ai,
        )
        self.kickoff_bibtex = to_raw_response_wrapper(
            papers.kickoff_bibtex,
        )
        self.kickoff_github = to_raw_response_wrapper(
            papers.kickoff_github,
        )
        self.kickoff_paper_categorization = to_raw_response_wrapper(
            papers.kickoff_paper_categorization,
        )
        self.kickoff_recent_papers = to_raw_response_wrapper(
            papers.kickoff_recent_papers,
        )
        self.mark_viewed = to_raw_response_wrapper(
            papers.mark_viewed,
        )
        self.process_abstract_embed = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                papers.process_abstract_embed,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_metadata = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                papers.process_metadata,  # pyright: ignore[reportDeprecated],
            )
        )
        self.request_ai_latest = to_raw_response_wrapper(
            papers.request_ai_latest,
        )
        self.request_ai_translation_latest = to_raw_response_wrapper(
            papers.request_ai_translation_latest,
        )
        self.set_github_repository = to_raw_response_wrapper(
            papers.set_github_repository,
        )
        self.toggle_follow = to_raw_response_wrapper(
            papers.toggle_follow,
        )
        self.translate_ai_overview = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                papers.translate_ai_overview,  # pyright: ignore[reportDeprecated],
            )
        )
        self.unclaim = to_raw_response_wrapper(
            papers.unclaim,
        )
        self.vote = to_raw_response_wrapper(
            papers.vote,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithRawResponse:
        return VersionsResourceWithRawResponse(self._papers.versions)

    @cached_property
    def metadata(self) -> MetadataResourceWithRawResponse:
        return MetadataResourceWithRawResponse(self._papers.metadata)

    @cached_property
    def ingest(self) -> IngestResourceWithRawResponse:
        return IngestResourceWithRawResponse(self._papers.ingest)

    @cached_property
    def private(self) -> PrivateResourceWithRawResponse:
        return PrivateResourceWithRawResponse(self._papers.private)

    @cached_property
    def kickoff_daily_github_stars(self) -> KickoffDailyGitHubStarsResourceWithRawResponse:
        return KickoffDailyGitHubStarsResourceWithRawResponse(self._papers.kickoff_daily_github_stars)

    @cached_property
    def v3(self) -> V3ResourceWithRawResponse:
        return V3ResourceWithRawResponse(self._papers.v3)

    @cached_property
    def v2(self) -> V2ResourceWithRawResponse:
        return V2ResourceWithRawResponse(self._papers.v2)


class AsyncPapersResourceWithRawResponse:
    def __init__(self, papers: AsyncPapersResource) -> None:
        self._papers = papers

        self.add_author = async_to_raw_response_wrapper(
            papers.add_author,
        )
        self.admin_vote = async_to_raw_response_wrapper(
            papers.admin_vote,
        )
        self.crx_abstract_click = async_to_raw_response_wrapper(
            papers.crx_abstract_click,
        )
        self.crx_abstract_hit = async_to_raw_response_wrapper(
            papers.crx_abstract_hit,
        )
        self.crx_pdf_click = async_to_raw_response_wrapper(
            papers.crx_pdf_click,
        )
        self.crx_pdf_hit = async_to_raw_response_wrapper(
            papers.crx_pdf_hit,
        )
        self.email_author = async_to_raw_response_wrapper(
            papers.email_author,
        )
        self.get_crx_paper_info = async_to_raw_response_wrapper(
            papers.get_crx_paper_info,
        )
        self.get_paper_info = async_to_raw_response_wrapper(
            papers.get_paper_info,
        )
        self.kickoff_abstract_embed = async_to_raw_response_wrapper(
            papers.kickoff_abstract_embed,
        )
        self.kickoff_ai = async_to_raw_response_wrapper(
            papers.kickoff_ai,
        )
        self.kickoff_bibtex = async_to_raw_response_wrapper(
            papers.kickoff_bibtex,
        )
        self.kickoff_github = async_to_raw_response_wrapper(
            papers.kickoff_github,
        )
        self.kickoff_paper_categorization = async_to_raw_response_wrapper(
            papers.kickoff_paper_categorization,
        )
        self.kickoff_recent_papers = async_to_raw_response_wrapper(
            papers.kickoff_recent_papers,
        )
        self.mark_viewed = async_to_raw_response_wrapper(
            papers.mark_viewed,
        )
        self.process_abstract_embed = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                papers.process_abstract_embed,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_metadata = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                papers.process_metadata,  # pyright: ignore[reportDeprecated],
            )
        )
        self.request_ai_latest = async_to_raw_response_wrapper(
            papers.request_ai_latest,
        )
        self.request_ai_translation_latest = async_to_raw_response_wrapper(
            papers.request_ai_translation_latest,
        )
        self.set_github_repository = async_to_raw_response_wrapper(
            papers.set_github_repository,
        )
        self.toggle_follow = async_to_raw_response_wrapper(
            papers.toggle_follow,
        )
        self.translate_ai_overview = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                papers.translate_ai_overview,  # pyright: ignore[reportDeprecated],
            )
        )
        self.unclaim = async_to_raw_response_wrapper(
            papers.unclaim,
        )
        self.vote = async_to_raw_response_wrapper(
            papers.vote,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithRawResponse:
        return AsyncVersionsResourceWithRawResponse(self._papers.versions)

    @cached_property
    def metadata(self) -> AsyncMetadataResourceWithRawResponse:
        return AsyncMetadataResourceWithRawResponse(self._papers.metadata)

    @cached_property
    def ingest(self) -> AsyncIngestResourceWithRawResponse:
        return AsyncIngestResourceWithRawResponse(self._papers.ingest)

    @cached_property
    def private(self) -> AsyncPrivateResourceWithRawResponse:
        return AsyncPrivateResourceWithRawResponse(self._papers.private)

    @cached_property
    def kickoff_daily_github_stars(self) -> AsyncKickoffDailyGitHubStarsResourceWithRawResponse:
        return AsyncKickoffDailyGitHubStarsResourceWithRawResponse(self._papers.kickoff_daily_github_stars)

    @cached_property
    def v3(self) -> AsyncV3ResourceWithRawResponse:
        return AsyncV3ResourceWithRawResponse(self._papers.v3)

    @cached_property
    def v2(self) -> AsyncV2ResourceWithRawResponse:
        return AsyncV2ResourceWithRawResponse(self._papers.v2)


class PapersResourceWithStreamingResponse:
    def __init__(self, papers: PapersResource) -> None:
        self._papers = papers

        self.add_author = to_streamed_response_wrapper(
            papers.add_author,
        )
        self.admin_vote = to_streamed_response_wrapper(
            papers.admin_vote,
        )
        self.crx_abstract_click = to_streamed_response_wrapper(
            papers.crx_abstract_click,
        )
        self.crx_abstract_hit = to_streamed_response_wrapper(
            papers.crx_abstract_hit,
        )
        self.crx_pdf_click = to_streamed_response_wrapper(
            papers.crx_pdf_click,
        )
        self.crx_pdf_hit = to_streamed_response_wrapper(
            papers.crx_pdf_hit,
        )
        self.email_author = to_streamed_response_wrapper(
            papers.email_author,
        )
        self.get_crx_paper_info = to_streamed_response_wrapper(
            papers.get_crx_paper_info,
        )
        self.get_paper_info = to_streamed_response_wrapper(
            papers.get_paper_info,
        )
        self.kickoff_abstract_embed = to_streamed_response_wrapper(
            papers.kickoff_abstract_embed,
        )
        self.kickoff_ai = to_streamed_response_wrapper(
            papers.kickoff_ai,
        )
        self.kickoff_bibtex = to_streamed_response_wrapper(
            papers.kickoff_bibtex,
        )
        self.kickoff_github = to_streamed_response_wrapper(
            papers.kickoff_github,
        )
        self.kickoff_paper_categorization = to_streamed_response_wrapper(
            papers.kickoff_paper_categorization,
        )
        self.kickoff_recent_papers = to_streamed_response_wrapper(
            papers.kickoff_recent_papers,
        )
        self.mark_viewed = to_streamed_response_wrapper(
            papers.mark_viewed,
        )
        self.process_abstract_embed = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                papers.process_abstract_embed,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_metadata = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                papers.process_metadata,  # pyright: ignore[reportDeprecated],
            )
        )
        self.request_ai_latest = to_streamed_response_wrapper(
            papers.request_ai_latest,
        )
        self.request_ai_translation_latest = to_streamed_response_wrapper(
            papers.request_ai_translation_latest,
        )
        self.set_github_repository = to_streamed_response_wrapper(
            papers.set_github_repository,
        )
        self.toggle_follow = to_streamed_response_wrapper(
            papers.toggle_follow,
        )
        self.translate_ai_overview = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                papers.translate_ai_overview,  # pyright: ignore[reportDeprecated],
            )
        )
        self.unclaim = to_streamed_response_wrapper(
            papers.unclaim,
        )
        self.vote = to_streamed_response_wrapper(
            papers.vote,
        )

    @cached_property
    def versions(self) -> VersionsResourceWithStreamingResponse:
        return VersionsResourceWithStreamingResponse(self._papers.versions)

    @cached_property
    def metadata(self) -> MetadataResourceWithStreamingResponse:
        return MetadataResourceWithStreamingResponse(self._papers.metadata)

    @cached_property
    def ingest(self) -> IngestResourceWithStreamingResponse:
        return IngestResourceWithStreamingResponse(self._papers.ingest)

    @cached_property
    def private(self) -> PrivateResourceWithStreamingResponse:
        return PrivateResourceWithStreamingResponse(self._papers.private)

    @cached_property
    def kickoff_daily_github_stars(self) -> KickoffDailyGitHubStarsResourceWithStreamingResponse:
        return KickoffDailyGitHubStarsResourceWithStreamingResponse(self._papers.kickoff_daily_github_stars)

    @cached_property
    def v3(self) -> V3ResourceWithStreamingResponse:
        return V3ResourceWithStreamingResponse(self._papers.v3)

    @cached_property
    def v2(self) -> V2ResourceWithStreamingResponse:
        return V2ResourceWithStreamingResponse(self._papers.v2)


class AsyncPapersResourceWithStreamingResponse:
    def __init__(self, papers: AsyncPapersResource) -> None:
        self._papers = papers

        self.add_author = async_to_streamed_response_wrapper(
            papers.add_author,
        )
        self.admin_vote = async_to_streamed_response_wrapper(
            papers.admin_vote,
        )
        self.crx_abstract_click = async_to_streamed_response_wrapper(
            papers.crx_abstract_click,
        )
        self.crx_abstract_hit = async_to_streamed_response_wrapper(
            papers.crx_abstract_hit,
        )
        self.crx_pdf_click = async_to_streamed_response_wrapper(
            papers.crx_pdf_click,
        )
        self.crx_pdf_hit = async_to_streamed_response_wrapper(
            papers.crx_pdf_hit,
        )
        self.email_author = async_to_streamed_response_wrapper(
            papers.email_author,
        )
        self.get_crx_paper_info = async_to_streamed_response_wrapper(
            papers.get_crx_paper_info,
        )
        self.get_paper_info = async_to_streamed_response_wrapper(
            papers.get_paper_info,
        )
        self.kickoff_abstract_embed = async_to_streamed_response_wrapper(
            papers.kickoff_abstract_embed,
        )
        self.kickoff_ai = async_to_streamed_response_wrapper(
            papers.kickoff_ai,
        )
        self.kickoff_bibtex = async_to_streamed_response_wrapper(
            papers.kickoff_bibtex,
        )
        self.kickoff_github = async_to_streamed_response_wrapper(
            papers.kickoff_github,
        )
        self.kickoff_paper_categorization = async_to_streamed_response_wrapper(
            papers.kickoff_paper_categorization,
        )
        self.kickoff_recent_papers = async_to_streamed_response_wrapper(
            papers.kickoff_recent_papers,
        )
        self.mark_viewed = async_to_streamed_response_wrapper(
            papers.mark_viewed,
        )
        self.process_abstract_embed = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                papers.process_abstract_embed,  # pyright: ignore[reportDeprecated],
            )
        )
        self.process_metadata = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                papers.process_metadata,  # pyright: ignore[reportDeprecated],
            )
        )
        self.request_ai_latest = async_to_streamed_response_wrapper(
            papers.request_ai_latest,
        )
        self.request_ai_translation_latest = async_to_streamed_response_wrapper(
            papers.request_ai_translation_latest,
        )
        self.set_github_repository = async_to_streamed_response_wrapper(
            papers.set_github_repository,
        )
        self.toggle_follow = async_to_streamed_response_wrapper(
            papers.toggle_follow,
        )
        self.translate_ai_overview = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                papers.translate_ai_overview,  # pyright: ignore[reportDeprecated],
            )
        )
        self.unclaim = async_to_streamed_response_wrapper(
            papers.unclaim,
        )
        self.vote = async_to_streamed_response_wrapper(
            papers.vote,
        )

    @cached_property
    def versions(self) -> AsyncVersionsResourceWithStreamingResponse:
        return AsyncVersionsResourceWithStreamingResponse(self._papers.versions)

    @cached_property
    def metadata(self) -> AsyncMetadataResourceWithStreamingResponse:
        return AsyncMetadataResourceWithStreamingResponse(self._papers.metadata)

    @cached_property
    def ingest(self) -> AsyncIngestResourceWithStreamingResponse:
        return AsyncIngestResourceWithStreamingResponse(self._papers.ingest)

    @cached_property
    def private(self) -> AsyncPrivateResourceWithStreamingResponse:
        return AsyncPrivateResourceWithStreamingResponse(self._papers.private)

    @cached_property
    def kickoff_daily_github_stars(self) -> AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse:
        return AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse(self._papers.kickoff_daily_github_stars)

    @cached_property
    def v3(self) -> AsyncV3ResourceWithStreamingResponse:
        return AsyncV3ResourceWithStreamingResponse(self._papers.v3)

    @cached_property
    def v2(self) -> AsyncV2ResourceWithStreamingResponse:
        return AsyncV2ResourceWithStreamingResponse(self._papers.v2)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["PaperRequestAITranslationLatestResponse"]


class PaperRequestAITranslationLatestResponse(BaseModel):
    data: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3GetViewedHistoryResponse", "V3GetViewedHistoryResponseItem"]


class V3GetViewedHistoryResponseItem(BaseModel):
    id: str

    abstract: str

    image_url: Optional[str] = FieldInfo(alias="imageUrl", default=None)

    paper_id: str = FieldInfo(alias="paperId")
    """A versionless universal paper ID (e.g. 1706.03762)"""

    publication_date: str = FieldInfo(alias="publicationDate")

    public_total_votes: float = FieldInfo(alias="publicTotalVotes")

    title: str

    topics: List[str]

    viewed_at: str = FieldInfo(alias="viewedAt")


V3GetViewedHistoryResponse: TypeAlias = List[V3GetViewedHistoryResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3RetrieveFullTextResponse", "Page"]


class Page(BaseModel):
    page_number: float = FieldInfo(alias="pageNumber")

    text: str


class V3RetrieveFullTextResponse(BaseModel):
    pages: List[Page]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import (
    IngestIngestLatestResponse,
    IngestIngestVersionResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestIngest:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_latest(self, client: AlphaxivCat) -> None:
        ingest = client.papers.ingest.ingest_latest(
            upid="x",
        )
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_latest_with_all_params(self, client: AlphaxivCat) -> None:
        ingest = client.papers.ingest.ingest_latest(
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_ingest_latest(self, client: AlphaxivCat) -> None:
        response = client.papers.ingest.with_raw_response.ingest_latest(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = response.parse()
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_ingest_latest(self, client: AlphaxivCat) -> None:
        with client.papers.ingest.with_streaming_response.ingest_latest(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = response.parse()
            assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_ingest_latest(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.ingest.with_raw_response.ingest_latest(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_version(self, client: AlphaxivCat) -> None:
        ingest = client.papers.ingest.ingest_version(
            version_label="x",
            upid="x",
        )
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_ingest_version_with_all_params(self, client: AlphaxivCat) -> None:
        ingest = client.papers.ingest.ingest_version(
            version_label="x",
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_ingest_version(self, client: AlphaxivCat) -> None:
        response = client.papers.ingest.with_raw_response.ingest_version(
            version_label="x",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = response.parse()
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_ingest_version(self, client: AlphaxivCat) -> None:
        with client.papers.ingest.with_streaming_response.ingest_version(
            version_label="x",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = response.parse()
            assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_ingest_version(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.ingest.with_raw_response.ingest_version(
                version_label="x",
                upid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version_label` but received ''"):
            client.papers.ingest.with_raw_response.ingest_version(
                version_label="",
                upid="x",
            )


class TestAsyncIngest:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_latest(self, async_client: AsyncAlphaxivCat) -> None:
        ingest = await async_client.papers.ingest.ingest_latest(
            upid="x",
        )
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_latest_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        ingest = await async_client.papers.ingest.ingest_latest(
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_ingest_latest(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.ingest.with_raw_response.ingest_latest(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = await response.parse()
        assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_ingest_latest(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.ingest.with_streaming_response.ingest_latest(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = await response.parse()
            assert_matches_type(IngestIngestLatestResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_ingest_latest(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.ingest.with_raw_response.ingest_latest(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_version(self, async_client: AsyncAlphaxivCat) -> None:
        ingest = await async_client.papers.ingest.ingest_version(
            version_label="x",
            upid="x",
        )
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_ingest_version_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        ingest = await async_client.papers.ingest.ingest_version(
            version_label="x",
            upid="x",
            prevent_tracking="preventTracking",
        )
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_ingest_version(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.ingest.with_raw_response.ingest_version(
            version_label="x",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        ingest = await response.parse()
        assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_ingest_version(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.ingest.with_streaming_response.ingest_version(
            version_label="x",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            ingest = await response.parse()
            assert_matches_type(IngestIngestVersionResponse, ingest, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_ingest_version(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.ingest.with_raw_response.ingest_version(
                version_label="x",
                upid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version_label` but received ''"):
            await async_client.papers.ingest.with_raw_response.ingest_version(
                version_label="",
                upid="x",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .archive_list_params import ArchiveListParams as ArchiveListParams
from .archive_create_params import ArchiveCreateParams as ArchiveCreateParams
from .archive_list_response import ArchiveListResponse as ArchiveListResponse
from .archive_create_response import ArchiveCreateResponse as ArchiveCreateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V2GetChatsResponse", "V2GetChatsResponseItem"]


class V2GetChatsResponseItem(BaseModel):
    id: str

    newest_message: float = FieldInfo(alias="newestMessage")
    """UNIX milliseconds"""

    title: str


V2GetChatsResponse: TypeAlias = List[V2GetChatsResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3RetrieveResponse", "Resource", "Version"]


class Resource(BaseModel):
    id: str

    description: str

    language: str

    stars: float

    type: Literal["github"]

    url: str


class Version(BaseModel):
    id: str

    label: str

    order: float


class V3RetrieveResponse(BaseModel):
    abstract: str

    citation_bibtex: Optional[str] = FieldInfo(alias="citationBibtex", default=None)

    citations_count: float = FieldInfo(alias="citationsCount")

    first_publication_date: float = FieldInfo(alias="firstPublicationDate")

    google_citation_id: Optional[str] = FieldInfo(alias="googleCitationId", default=None)

    group_id: str = FieldInfo(alias="groupId")

    license: Optional[str] = None

    publication_date: float = FieldInfo(alias="publicationDate")

    resources: List[Resource]

    source_name: str = FieldInfo(alias="sourceName")

    source_url: str = FieldInfo(alias="sourceUrl")

    title: str

    type: Literal["public", "private", "community"]

    universal_id: str = FieldInfo(alias="universalId")

    uploader: Optional[str] = None

    version_id: str = FieldInfo(alias="versionId")

    version_label: str = FieldInfo(alias="versionLabel")

    version_order: float = FieldInfo(alias="versionOrder")

    versions: List[Version]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3UpdatePreferencesParams", "Banner", "Base", "BaseAssistantCustomStyle"]


class V3UpdatePreferencesParams(TypedDict, total=False):
    banners: Iterable[Banner]

    base: Base


class Banner(TypedDict, total=False):
    link: Required[Optional[str]]

    name: Required[str]

    type: Required[Literal["success", "info", "warning", "error"]]


class BaseAssistantCustomStyle(TypedDict, total=False):
    id: Required[str]

    instructions: Required[str]

    name: Required[str]


class Base(TypedDict, total=False):
    assistant_custom_styles: Annotated[Iterable[BaseAssistantCustomStyle], PropertyInfo(alias="assistantCustomStyles")]

    assistant_style_selection: Annotated[
        Union[Literal["default", "concise", "tutor", "thorough", "skeptical"], str],
        PropertyInfo(alias="assistantStyleSelection"),
    ]

    default_private_paper_sidebar_tab: Annotated[
        Optional[Literal["assistant", "notes", "similar"]], PropertyInfo(alias="defaultPrivatePaperSidebarTab")
    ]

    default_public_paper_sidebar_tab: Annotated[
        Optional[Literal["comments", "assistant", "similar", "notes", "social"]],
        PropertyInfo(alias="defaultPublicPaperSidebarTab"),
    ]

    feed_sort: Annotated[
        Literal["Hot", "Comments", "Views", "Likes", "GitHub", "Twitter (X)", "Recommended"],
        PropertyInfo(alias="feedSort"),
    ]

    is_dark_mode_enabled: Annotated[bool, PropertyInfo(alias="isDarkModeEnabled")]

    is_debug_mode_enabled: Annotated[bool, PropertyInfo(alias="isDebugModeEnabled")]

    is_members_sidebar_visible: Annotated[bool, PropertyInfo(alias="isMembersSidebarVisible")]

    preferred_language: Annotated[
        Optional[
            Literal[
                "am",
                "ar",
                "az",
                "bg",
                "bn",
                "ca",
                "cs",
                "da",
                "de",
                "el",
                "en",
                "es",
                "et",
                "fa",
                "fi",
                "fr",
                "gu",
                "ha",
                "he",
                "hi",
                "hr",
                "hu",
                "id",
                "it",
                "ja",
                "ka",
                "kn",
                "ko",
                "lt",
                "lv",
                "ml",
                "mr",
                "ms",
                "my",
                "ne",
                "nl",
                "no",
                "pa",
                "pl",
                "pt",
                "ro",
                "ru",
                "si",
                "sk",
                "sl",
                "sr",
                "sv",
                "sw",
                "ta",
                "te",
                "th",
                "tl",
                "tr",
                "uk",
                "ur",
                "uz",
                "vi",
                "yo",
                "zh",
            ]
        ],
        PropertyInfo(alias="preferredLanguage"),
    ]

    preferred_llm_model: Annotated[Optional[str], PropertyInfo(alias="preferredLlmModel")]

    reading_mode_enabled: Annotated[bool, PropertyInfo(alias="readingModeEnabled")]

    show_model_thinking: Annotated[bool, PropertyInfo(alias="showModelThinking")]

    tooling_pane_width: Annotated[Optional[float], PropertyInfo(alias="toolingPaneWidth")]

    web_search: Annotated[Literal["off", "full"], PropertyInfo(alias="webSearch")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "SharedRetrieveResponse",
    "ChildFolder",
    "ChildFolderPaper",
    "ChildFolderPaperAuthor",
    "ChildFolderPaperOrganization",
    "ChildFolderPaperUserAuthor",
    "ChildFolderPaperUserAuthorAvatar",
    "Folder",
    "FolderPaper",
    "FolderPaperAuthor",
    "FolderPaperOrganization",
    "FolderPaperUserAuthor",
    "FolderPaperUserAuthorAvatar",
]


class ChildFolderPaperAuthor(BaseModel):
    id: str

    full_name: str

    user_id: Optional[str] = None

    username: Optional[str] = None


class ChildFolderPaperOrganization(BaseModel):
    image: Optional[str] = None

    name: str


class ChildFolderPaperUserAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class ChildFolderPaperUserAuthor(BaseModel):
    id: str

    avatar: Optional[List[ChildFolderPaperUserAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class ChildFolderPaper(BaseModel):
    abstract: str

    added_at: str = FieldInfo(alias="addedAt")

    authors: List[ChildFolderPaperAuthor]

    citation: Optional[str] = None

    image_url: Optional[str] = FieldInfo(alias="imageUrl", default=None)

    organizations: List[ChildFolderPaperOrganization]

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    publication_date: str = FieldInfo(alias="publicationDate")

    title: str

    topics: List[str]

    type: Literal["private", "community", "public"]

    universal_paper_id: str = FieldInfo(alias="universalPaperId")

    user_authors: List[ChildFolderPaperUserAuthor] = FieldInfo(alias="userAuthors")


class ChildFolder(BaseModel):
    id: str

    name: str

    order: float

    papers: List[ChildFolderPaper]

    parent_id: Optional[str] = FieldInfo(alias="parentId", default=None)

    sharing_status: Literal["not_shared", "shared"] = FieldInfo(alias="sharingStatus")

    type: str


class FolderPaperAuthor(BaseModel):
    id: str

    full_name: str

    user_id: Optional[str] = None

    username: Optional[str] = None


class FolderPaperOrganization(BaseModel):
    image: Optional[str] = None

    name: str


class FolderPaperUserAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class FolderPaperUserAuthor(BaseModel):
    id: str

    avatar: Optional[List[FolderPaperUserAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class FolderPaper(BaseModel):
    abstract: str

    added_at: str = FieldInfo(alias="addedAt")

    authors: List[FolderPaperAuthor]

    citation: Optional[str] = None

    image_url: Optional[str] = FieldInfo(alias="imageUrl", default=None)

    organizations: List[FolderPaperOrganization]

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    publication_date: str = FieldInfo(alias="publicationDate")

    title: str

    topics: List[str]

    type: Literal["private", "community", "public"]

    universal_paper_id: str = FieldInfo(alias="universalPaperId")

    user_authors: List[FolderPaperUserAuthor] = FieldInfo(alias="userAuthors")


class Folder(BaseModel):
    id: str

    name: str

    order: float

    papers: List[FolderPaper]

    parent_id: Optional[str] = FieldInfo(alias="parentId", default=None)

    sharing_status: Literal["not_shared", "shared"] = FieldInfo(alias="sharingStatus")

    type: str


class SharedRetrieveResponse(BaseModel):
    child_folders: List[ChildFolder] = FieldInfo(alias="childFolders")

    folder: Folder

    owner_name: str = FieldInfo(alias="ownerName")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v2_chat_params import V2ChatParams as V2ChatParams
from .v2_edit_chat_params import V2EditChatParams as V2EditChatParams
from .v2_get_chats_params import V2GetChatsParams as V2GetChatsParams
from .v2_get_chats_response import V2GetChatsResponse as V2GetChatsResponse
from .v2_get_url_metadata_params import V2GetURLMetadataParams as V2GetURLMetadataParams
from .v2_get_url_metadata_response import V2GetURLMetadataResponse as V2GetURLMetadataResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["PaperAddAuthorResponse", "Data"]


class Data(BaseModel):
    warning: str


class PaperAddAuthorResponse(BaseModel):
    accept: Literal[0, 1, 2]

    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .v2.v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.assistant_upload_file_response import AssistantUploadFileResponse

__all__ = ["AssistantResource", "AsyncAssistantResource"]


class AssistantResource(SyncAPIResource):
    @cached_property
    def v2(self) -> V2Resource:
        return V2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AssistantResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AssistantResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AssistantResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AssistantResourceWithStreamingResponse(self)

    def upload_file(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AssistantUploadFileResponse:
        """
        Upload a file for use with the assistant (max 30MB)

        Source file: `api-server/src/controllers/v1/assistant/upload-file.controller.ts`
        """
        return self._post(
            "/v1/assistant/upload-file",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AssistantUploadFileResponse,
        )


class AsyncAssistantResource(AsyncAPIResource):
    @cached_property
    def v2(self) -> AsyncV2Resource:
        return AsyncV2Resource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncAssistantResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAssistantResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAssistantResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncAssistantResourceWithStreamingResponse(self)

    async def upload_file(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AssistantUploadFileResponse:
        """
        Upload a file for use with the assistant (max 30MB)

        Source file: `api-server/src/controllers/v1/assistant/upload-file.controller.ts`
        """
        return await self._post(
            "/v1/assistant/upload-file",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AssistantUploadFileResponse,
        )


class AssistantResourceWithRawResponse:
    def __init__(self, assistant: AssistantResource) -> None:
        self._assistant = assistant

        self.upload_file = to_raw_response_wrapper(
            assistant.upload_file,
        )

    @cached_property
    def v2(self) -> V2ResourceWithRawResponse:
        return V2ResourceWithRawResponse(self._assistant.v2)


class AsyncAssistantResourceWithRawResponse:
    def __init__(self, assistant: AsyncAssistantResource) -> None:
        self._assistant = assistant

        self.upload_file = async_to_raw_response_wrapper(
            assistant.upload_file,
        )

    @cached_property
    def v2(self) -> AsyncV2ResourceWithRawResponse:
        return AsyncV2ResourceWithRawResponse(self._assistant.v2)


class AssistantResourceWithStreamingResponse:
    def __init__(self, assistant: AssistantResource) -> None:
        self._assistant = assistant

        self.upload_file = to_streamed_response_wrapper(
            assistant.upload_file,
        )

    @cached_property
    def v2(self) -> V2ResourceWithStreamingResponse:
        return V2ResourceWithStreamingResponse(self._assistant.v2)


class AsyncAssistantResourceWithStreamingResponse:
    def __init__(self, assistant: AsyncAssistantResource) -> None:
        self._assistant = assistant

        self.upload_file = async_to_streamed_response_wrapper(
            assistant.upload_file,
        )

    @cached_property
    def v2(self) -> AsyncV2ResourceWithStreamingResponse:
        return AsyncV2ResourceWithStreamingResponse(self._assistant.v2)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_get_moderator_feed_params import V1GetModeratorFeedParams as V1GetModeratorFeedParams
from .v1_get_moderator_feed_response import V1GetModeratorFeedResponse as V1GetModeratorFeedResponse
from .v1_lookup_user_by_email_params import V1LookupUserByEmailParams as V1LookupUserByEmailParams
from .v1_lookup_user_by_email_response import V1LookupUserByEmailResponse as V1LookupUserByEmailResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.users.v3.following import (
    OrganizationListResponse,
    OrganizationToggleResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestOrganizations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: AlphaxivCat) -> None:
        organization = client.users.v3.following.organizations.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(OrganizationListResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: AlphaxivCat) -> None:
        response = client.users.v3.following.organizations.with_raw_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        organization = response.parse()
        assert_matches_type(OrganizationListResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: AlphaxivCat) -> None:
        with client.users.v3.following.organizations.with_streaming_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            organization = response.parse()
            assert_matches_type(OrganizationListResponse, organization, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_list(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.following.organizations.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle(self, client: AlphaxivCat) -> None:
        organization = client.users.v3.following.organizations.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        )
        assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle(self, client: AlphaxivCat) -> None:
        response = client.users.v3.following.organizations.with_raw_response.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        organization = response.parse()
        assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle(self, client: AlphaxivCat) -> None:
        with client.users.v3.following.organizations.with_streaming_response.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            organization = response.parse()
            assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.following.organizations.with_raw_response.toggle(
                id="",
                organization="x",
            )


class TestAsyncOrganizations:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAlphaxivCat) -> None:
        organization = await async_client.users.v3.following.organizations.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(OrganizationListResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.following.organizations.with_raw_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        organization = await response.parse()
        assert_matches_type(OrganizationListResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.following.organizations.with_streaming_response.list(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            organization = await response.parse()
            assert_matches_type(OrganizationListResponse, organization, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.following.organizations.with_raw_response.list(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle(self, async_client: AsyncAlphaxivCat) -> None:
        organization = await async_client.users.v3.following.organizations.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        )
        assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.following.organizations.with_raw_response.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        organization = await response.parse()
        assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.following.organizations.with_streaming_response.toggle(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            organization="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            organization = await response.parse()
            assert_matches_type(OrganizationToggleResponse, organization, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.following.organizations.with_raw_response.toggle(
                id="",
                organization="x",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.users.preferences import EmailGetResponse, EmailUpdateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestEmail:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: AlphaxivCat) -> None:
        email = client.users.preferences.email.update()
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: AlphaxivCat) -> None:
        email = client.users.preferences.email.update(
            direct_notifications=True,
            relevant_activity=True,
        )
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: AlphaxivCat) -> None:
        response = client.users.preferences.email.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: AlphaxivCat) -> None:
        with client.users.preferences.email.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get(self, client: AlphaxivCat) -> None:
        email = client.users.preferences.email.get()
        assert_matches_type(EmailGetResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get(self, client: AlphaxivCat) -> None:
        response = client.users.preferences.email.with_raw_response.get()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = response.parse()
        assert_matches_type(EmailGetResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get(self, client: AlphaxivCat) -> None:
        with client.users.preferences.email.with_streaming_response.get() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = response.parse()
            assert_matches_type(EmailGetResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncEmail:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.users.preferences.email.update()
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.users.preferences.email.update(
            direct_notifications=True,
            relevant_activity=True,
        )
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.preferences.email.with_raw_response.update()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailUpdateResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.preferences.email.with_streaming_response.update() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailUpdateResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get(self, async_client: AsyncAlphaxivCat) -> None:
        email = await async_client.users.preferences.email.get()
        assert_matches_type(EmailGetResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.preferences.email.with_raw_response.get()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        email = await response.parse()
        assert_matches_type(EmailGetResponse, email, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.preferences.email.with_streaming_response.get() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            email = await response.parse()
            assert_matches_type(EmailGetResponse, email, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V1GetModeratorFeedResponse",
    "V1GetModeratorFeedResponseItem",
    "V1GetModeratorFeedResponseItemAuthor",
    "V1GetModeratorFeedResponseItemAuthorAvatar",
]


class V1GetModeratorFeedResponseItemAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class V1GetModeratorFeedResponseItemAuthor(BaseModel):
    id: str

    avatar: Optional[List[V1GetModeratorFeedResponseItemAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class V1GetModeratorFeedResponseItem(BaseModel):
    id: str

    author: V1GetModeratorFeedResponseItemAuthor

    body: str

    date: str

    flag_count: float = FieldInfo(alias="flagCount")

    is_addressed: bool = FieldInfo(alias="isAddressed")

    is_closed: bool = FieldInfo(alias="isClosed")

    is_flag_addressed: bool = FieldInfo(alias="isFlagAddressed")

    paper_title: str = FieldInfo(alias="paperTitle")

    selected_text: Optional[str] = FieldInfo(alias="selectedText", default=None)

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")


V1GetModeratorFeedResponse: TypeAlias = List[V1GetModeratorFeedResponseItem]
